<template>
  <!-- form -->
  <validation-observer ref="refForm">
    <b-form>
      <b-row>
        <b-col cols="12">
          <b-form-group
            label="中類名稱"
            label-for="name"
            label-cols-md="4"
          >
            <validation-provider
              #default="{ errors }"
              name="中類名稱"
              rules="required"
            >
              <b-form-input
                id="name"
                v-model="name"
                :state="errors.length > 0 ? false:null"
                placeholder="中類名稱"
              />
              <small class="text-danger">{{ strErrors.name }}</small>
            </validation-provider>
          </b-form-group>
        </b-col>
        <b-col cols="12">
          <b-form-group
            label="中類代碼"
            label-for="code"
            label-cols-md="4"
          >
            <validation-provider
              #default="{ errors }"
              name="中類代碼"
              rules="required"
            >
              <b-form-input
                id="code"
                v-model="code"
                :state="errors.length > 0 ? false:null"
                placeholder="中類代碼 | 兩碼數字"
              />
              <small class="text-danger">{{ strErrors.code }}</small>
            </validation-provider>
          </b-form-group>
        </b-col>
        <b-col cols="12">
          <b-form-group
            label="大類"
            label-cols-md="4"
          >
            <validation-provider
              #default="{ errors }"
              name="大類"
              rules="required"
            >
              <v-select
                v-model="products_class_main_id"
                :dir="$store.state.appConfig.isRTL ? 'rtl' : 'ltr'"
                multiple
                label="title"
                :options="options"
              />
              <small class="text-danger">{{ strErrors.products_class_main_id }}</small>
            </validation-provider>
          </b-form-group>
        </b-col>
        <b-col cols="12">
          <b-button
            variant="primary"
            type="submit"
            @click.prevent="validationForm"
          >
            完成
          </b-button>
        </b-col>
      </b-row>
    </b-form>
  </validation-observer>
</template>

<script>
import BCardCode from '@core/components/b-card-code'
import { ValidationProvider, ValidationObserver } from 'vee-validate'
import {
  BFormInput, BFormGroup, BForm, BRow, BCol, BButton, BCardText,
} from 'bootstrap-vue'
import vSelect from 'vue-select'
import { required, email } from '@validations'
import store from '@/store'
import router from '@/router'
import { ref, onUnmounted } from '@vue/composition-api'
import productClassSubStoreModule from '../productClassSubStoreModule'

export default {
  components: {
    BCardCode,
    vSelect,
    ValidationProvider,
    ValidationObserver,
    BCardText,
    BFormInput,
    BFormGroup,
    BForm,
    BRow,
    BCol,
    BButton,
  },
  setup() {
    const USER_APP_STORE_MODULE_NAME = 'information'

    // Register module
    if (!store.hasModule(USER_APP_STORE_MODULE_NAME)) store.registerModule(USER_APP_STORE_MODULE_NAME, productClassSubStoreModule)

    // UnRegister on leave
    onUnmounted(() => {
      if (store.hasModule(USER_APP_STORE_MODULE_NAME)) store.unregisterModule(USER_APP_STORE_MODULE_NAME)
    })

    const refForm = ref(null)
    const code = ref('')
    const name = ref('')
    const products_class_main_id = ref(null)
    const options = ref([])
    const strErrors = ref({
      code: '',
      name: '',
      products_class_main_id: '',
    })

    const validationForm = () => {
      addProductClassSub()
      // refForm.value.validate().then(success => {
      //   if (success) {
      //     // eslint-disable-next-line
      //     alert('form submitted!')
      //     addProductClassSub()
      //   }
      // })
    }

    const addProductClassSub = () => {
      store
        .dispatch('information/addProductClassSub', {
          code: code.value,
          name: name.value,
          products_class_main_id: products_class_main_id.value,
        })
        .then(response => {
          for (var prop in strErrors.value) {
            strErrors.value[prop] = '';
          }
          let result = response.data;
          if (result.message == 'success') {
            router.push({ name: 'information-product-class-sub' })
          } else {
            for (var prop in result.data) {
              strErrors.value[prop] = result.data[prop].join(' | ');
            }
          }
        })
    }

    const getOptions = (ctx, callback) => {
      store
        .dispatch('information/fetchProductClassMains', {
        })
        .then(response => {
          const { productClassMains, total } = response
          productClassMains.forEach(productClassMain => {
            options.value.push({ title: productClassMain.code + ' | ' + productClassMain.name, value: productClassMain.id });
          })
        })
    }

    getOptions()

    return {
      refForm,
      code,
      name,
      products_class_main_id,
      options,
      strErrors,
      validationForm,
      addProductClassSub,
    }
  },
}
</script>
